Documentation
¶
Overview ¶
Package serial provides a serial port, which provides the io.ReadWriter interface, that provides the connection between the at or gsm packages and the physical modem.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶ added in v0.2.0
type Config struct {
// contains filtered or unexported fields
}
Config contains the configuration parameters of the serial port.
Click to show internal directories.
Click to hide internal directories.